"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.readFile = readFile;
exports.inputContentSize = exports.inputImageSize = void 0;

var fse = _interopRequireWildcard(require("fs-extra"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

const inputImageSize = 108;
exports.inputImageSize = inputImageSize;
const inputContentSize = 72;
exports.inputContentSize = inputContentSize;

async function readFile(filePath) {
  console.debug("Reading file", filePath);
  const fileStats = await fse.stat(filePath);
  return {
    fileStats: fileStats,
    read: lazyLoadProvider(filePath)
  };
}

function lazyLoadProvider(filePath) {
  let lazyLoadedData = undefined;
  return function () {
    if (lazyLoadedData === undefined) {
      lazyLoadedData = loadData(filePath);
    }

    return lazyLoadedData;
  };
}

async function loadData(filePath) {
  const sharpImport = await Promise.resolve().then(() => _interopRequireWildcard(require("sharp")));
  const warmedSharpInstance = await warmupSharp(sharpImport.default);
  const imageData = await readImage(warmedSharpInstance, filePath);
  return {
    sharp: warmedSharpInstance,
    imageData: imageData
  };
} // First run might cause a xmllib error, run safe warmup
// See https://github.com/lovell/sharp/issues/1593


async function warmupSharp(sharp) {
  try {
    await sharp(Buffer.from(`<svg xmlns="http://www.w3.org/2000/svg"><rect width="1" height="1" /></svg>`, "utf-8")).metadata();
  } catch {}

  return sharp;
}

async function readImage(sharp, filePath) {
  const fileData = await fse.readFile(filePath);
  const sharpInstance = sharp(fileData);
  const [metadata, stats] = await Promise.all([sharpInstance.metadata(), sharpInstance.stats()]);
  const validMetadata = validateMetadata(metadata);
  const validStats = validateStats(stats);
  return {
    data: fileData,
    metadata: validMetadata,
    stats: validStats
  };
}

function validateMetadata(metadata) {
  if (metadata.format !== "svg") {
    throw new Error(`Unsupported image format ${metadata.format}. Only SVG images are supported.`);
  }

  if (!metadata.density || !metadata.width || !metadata.height) {
    throw new Error("Unsupported image, missing size and density");
  }

  if (metadata.width !== metadata.height) {
    throw new Error("Input image not square");
  } // TODO: Support different sized images


  if (metadata.width !== inputImageSize || metadata.height !== inputImageSize) {
    throw new Error("Input image size not 108x108");
  }

  return { ...metadata,
    format: metadata.format,
    width: metadata.width,
    height: metadata.height,
    density: metadata.density
  };
}

function validateStats(stats) {
  if (stats.isOpaque) {
    return { ...stats,
      isOpaque: stats.isOpaque
    };
  } else {
    throw new Error("Input image should be opaque");
  }
}